@@ -8,9 +8,6 @@ REVISIONS:
 #ifndef YLINALG_H
 #define YLINALG_H
 
-#ifndef lint
-static char YlinAlgId[] = "@(#) linalg.h version 1.1 1/15/91" ;
-#endif
 
 #define YEPSILON  1.0E-12
 #define YMIN     -1.0E-38
@@ -29,9 +26,9 @@ extern YMPTR Ymatrix_free( P1( YMPTR mptr ) ) ;
 extern YMPTR Ymatrix_transpose( P1( YMPTR mptr ) ) ;
 extern YMPTR Ymatrix_mult( P2(YMPTR aptr, YMPTR bptr ) ) ;
 extern YMPTR Ymatrix_sub( P2(YMPTR aptr, YMPTR bptr ) ) ;
-extern Ymatrix_disp( P1(YMPTR mptr ) ) ;
+extern void Ymatrix_disp( P1(YMPTR mptr ) ) ;
 extern YMPTR Ymatrix_eye( P1(INT size ) ) ;
-extern Ymatrix_zero( P1(YMPTR matrix ) ) ;
+extern void Ymatrix_zero( P1(YMPTR matrix ) ) ;
 extern YMPTR Ymatrix_copy( P1(YMPTR input ) ) ;
 extern YMPTR Ymatrix_linv( P1(YMPTR aptr ) ) ;
 extern YMPTR Ymatrix_cofactors( P1(YMPTR aptr ) ) ;
