@@ -61,9 +61,6 @@
 		    Sat Apr 18 11:29:50 EDT 1992 - added compactor
 			program entry - CMPT.
    ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) yreadpar.c (Yale) version 1.6 10/1/91" ;
-#endif
 
 #include <string.h>
 #include <yalecad/file.h>
@@ -703,8 +700,8 @@ char *object1, *object2 ;
 	    object1, object2 );
 	M( ERRMSG, "Yreadpar_spacing", YmsgG ) ;
 	M( ERRMSG, NULL, "\tDefaulting to zero.\n\n" ) ;
-	return( 0 ) ;
     }
+	return( 0 ) ;
 
 } /* end Yreadpar_spacing */
 
@@ -765,8 +762,8 @@ char *object ;
 	    object );
 	M( ERRMSG, "Yreadpar_layer_res", YmsgG ) ;
 	M( ERRMSG, NULL, "\tDefaulting to zero.\n\n" ) ;
-	return( 0 ) ;
     }
+	return( 0 ) ;
 
 } /* end Yreadpar_layer_res */
 
@@ -789,8 +786,8 @@ char *object ;
 	    object );
 	M( ERRMSG, "Yreadpar_layer_cap", YmsgG ) ;
 	M( ERRMSG, NULL, "\tDefaulting to zero.\n\n" ) ;
-	return( (DOUBLE) 0.0 ) ;
     }
+	return( (DOUBLE) 0.0 ) ;
 
 } /* end Yreadpar_layer_cap */
 
@@ -814,8 +811,8 @@ char *object ;
 	    object );
 	M( ERRMSG, "Yreadpar_layer_HnotV", YmsgG ) ;
 	M( ERRMSG, NULL, "\tDefaulting to horizontal.\n\n" ) ;
-	return( TRUE ) ;
     }
+	return( TRUE ) ;
 
 } /* end Yreadpar_layer_HnotV */
 
@@ -838,8 +835,8 @@ char *object ;
 	    object );
 	M( ERRMSG, "Yreadpar_layer2id", YmsgG ) ;
 	M( ERRMSG, NULL, "\tDefaulting to horizontal.\n\n" ) ;
-	return( TRUE ) ;
     }
+	return( TRUE ) ;
 
 } /* end Yreadpar_layer2id */
 
@@ -888,8 +885,8 @@ char *object1, *object2 ;
 	    "Could not find a via between layers %s and %s.\n",
 	    object1, object2 );
 	M( ERRMSG, "Yreadpar_vianame", YmsgG ) ;
-	return( NIL(char *) ) ;
     }
+	return( NIL(char *) ) ;
 
 } /* end Yreadpar_vianame */
 
