@@ -46,9 +46,6 @@ DATE:	    Nov	29, 1990
 REVISIONS:  Fri Jan 25 17:50:54 PST 1991 - added mirror row feature.
 	    Sat Sep 21 15:41:10 EDT 1991 - updated for memory.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) merge.c (Yale) version 3.5 5/14/92" ;
-#endif
 
 #include <stdio.h>
 #include <yalecad/debug.h>
@@ -57,12 +54,14 @@ static char SccsId[] = "@(#) merge.c (Yale) version 3.5 5/14/92" ;
 
 
 
-static check_max_length();
-static merge_adjacent_tiles();
+static void check_max_length();
+static void merge_adjacent_tiles();
+void merge_downward( TILE_BOX *begin_tile );
+void merge_upward( TILE_BOX *begin_tile );
 
 
 
-merge_tiles()
+void merge_tiles()
 {
     TILE_BOX *tileptr ; /* current tile */
 
@@ -73,8 +72,7 @@ merge_tiles()
     }
 } /* end merge_tiles */
 
-merge_upward( begin_tile )
-TILE_BOX *begin_tile ;
+void merge_upward( TILE_BOX *begin_tile )
 {
     INT left ;          /* left edge of merge tile */
     INT right ;         /* right edge of merge tile */
@@ -224,8 +222,7 @@ TILE_BOX *begin_tile ;
 
 } /* end merge_upward */
 
-merge_downward( begin_tile )
-TILE_BOX *begin_tile ;
+void merge_downward( TILE_BOX *begin_tile )
 {
     INT left ;          /* left edge of merge tile */
     INT right ;         /* right edge of merge tile */
@@ -377,7 +374,7 @@ TILE_BOX *begin_tile ;
 
 } /* end merge_downward */
 
-merge_right( begin_tile )
+void merge_right( begin_tile )
 TILE_BOX *begin_tile ;
 {
     INT bottom ;        /* bottom edge of merge tile */
@@ -524,7 +521,7 @@ TILE_BOX *begin_tile ;
 
 } /* end merge_right */
 
-merge_left( begin_tile )
+void merge_left( begin_tile )
 TILE_BOX *begin_tile ;
 {
     INT bottom ;        /* bottom edge of merge tile */
@@ -668,7 +665,7 @@ TILE_BOX *begin_tile ;
 
 } /* end merge_left */
 
-static check_max_length( tileptr )
+static void check_max_length( tileptr )
 TILE_BOX *tileptr ;
 {
     INT length ;              /* length of tile */
@@ -678,7 +675,7 @@ TILE_BOX *tileptr ;
 
 }/* end check_max_length */
 
-renumber_tiles()
+void renumber_tiles()
 {
     INT count ;              /* count the tiles */
     TILE_BOX *tileptr ;      /* current tile */
@@ -688,7 +685,7 @@ renumber_tiles()
     }
 } /* end renumber_tiles() */
 
-static merge_adjacent_tiles()
+static void merge_adjacent_tiles()
 {
 
     TILE_BOX *tileptr1 , *tileptr2 , *tileptr ;
@@ -732,7 +729,7 @@ REDO:
     return ;
 }/* end merge_adjacent_tiles */
 
-dtiles()
+void dtiles()
 {
     TILE_BOX *tptr ;      /* current tile */
 
