@@ -52,9 +52,6 @@ REVISIONS:  Apr 25, 1989 - added graphics loop to program.
 	    Fri Mar 29 14:13:22 EST 1991 - temp fix for 2D graphics
 		avoids arbitrary edge explosion.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) cdraw.c version 7.5 3/29/91" ;
-#endif
 
 #ifndef NOGRAPHICS 
 
@@ -92,13 +89,15 @@ static BOOL drawEdgeLabelS = FALSE ;
 static BOOL drawChanGraphS = TRUE ;
 static INT  zspanS ;
 
-init_graphics( argc, argv, windowId )
+void draw_changraph();
+
+void init_graphics( argc, argv, windowId )
 INT argc, windowId ;
 char *argv[] ;
 {
     char *host, *Ygetenv() ;
     int  xpandx, xpandy ;
-    INT draw_the_data() ;
+    void draw_the_data() ;
 
     /* we need to find host for display */
     if(!(host = Ygetenv("DISPLAY"))) {
@@ -110,14 +109,14 @@ char *argv[] ;
     if( windowId ){
 	/* init windows as a parasite */
 	if( !( TWinitParasite(argc,argv,TWnumcolors(),TWstdcolors(),
-	    FALSE, MENU, draw_the_data, windowId ))){
+	    FALSE, MENU,  (INT (*)()) draw_the_data, windowId ))){
 	    M(ERRMSG,"initgraphics","Aborting graphics.");
 	    graphicsG = FALSE ;
 	    return ;
 	}
     } else {
 	if(!(TWinitGraphics(argc,argv,TWnumcolors(),TWstdcolors(),
-	    FALSE, MENU, draw_the_data ))){
+	    FALSE, MENU, (INT (*)()) draw_the_data ))){
 	    M(ERRMSG,"init_graphics","Aborting graphics.");
 	    graphicsG = FALSE ;
 	    return ;
@@ -134,7 +133,7 @@ char *argv[] ;
     }
 }
 
-set_draw_critical( flag ) 
+void set_draw_critical( flag ) 
 BOOL flag ;
 {
 
@@ -147,7 +146,7 @@ BOOL flag ;
 } /* end set_draw_critical */
 
 /* draw_the_data routine draws compaction graph */
-INT draw_the_data()
+void draw_the_data()
 {
 
     INT  i ;
@@ -383,7 +382,7 @@ INT draw_the_data()
 } /* end draw_the_data */
 
 /* heart of the graphic system processes user input */
-process_graphics()
+void process_graphics()
 {
 
     int x1, y1, x2, y2 ; /* coordinates for fixing cells and neighhds */
@@ -554,7 +553,7 @@ process_graphics()
 
 
 /* how to draw the channel graph */
-draw_changraph()
+void draw_changraph()
 {
     INT i ;                        /* temp counter */
     INT color ;                    /* color of edge */
