@@ -116,9 +116,6 @@ REVISIONS:  Oct 27, 1988 - added add_cell_to_group, initializeCorner
 	    Fri Oct 18 00:06:37 EDT 1991 - moved buster code to library
 		and updated for new NIL definition.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) initialize.c version 3.24 10/18/91" ;
-#endif
 
 #include <string.h>
 #include <custom.h>
@@ -129,6 +126,7 @@ static char SccsId[] = "@(#) initialize.c version 3.24 10/18/91" ;
 #include <yalecad/hash.h>
 #include <yalecad/debug.h>
 #include <yalecad/string.h>
+#include <findside.h>
 
 
 /* below is what we expect to be a large floorplanning input */
@@ -155,6 +153,13 @@ static char SccsId[] = "@(#) initialize.c version 3.24 10/18/91" ;
     } \
 } \
 
+#define ERRORABORTINT() \
+{ \
+    if( errorFlagS ){ \
+	return -1; /* don't do any work for errors */ \
+    } \
+} \
+
 /* ######################  STATIC definitions ######################### */
 static INT  curCellTypeS ;  /* current cell type - ie, softcell,pad etc.*/
 static INT  cellinstanceS ; /* number of instances of current cell      */
@@ -198,12 +203,12 @@ PINBOXPTR findTerminal() ;
 
 
 
-static check_pos();
+static void check_pos();
 
 
 
 /* set processing switch to avoid work when an error is found */
-setErrorFlag()
+void setErrorFlag()
 {
 errorFlagS = TRUE ;
 } /* end setErrorFlag */
@@ -217,7 +222,7 @@ return( netTableS ) ;
 /* ***************************************************************** */
 
 /* initialize global and static information */
-initCellInfo()
+void initCellInfo()
 {
 numcellsG = 0 ;
 numnetsG = 0 ;
@@ -255,7 +260,7 @@ cellarrayG = (CELLBOXPTR *)Ysafe_malloc(cellAllocS*sizeof(CELLBOXPTR));
 /* ***************************************************************** */
 
 /* cleanup operations at the end of readcells */
-cleanupReadCells()
+void cleanupReadCells()
 {
     INT cell ;           /* cell counter */
     PADBOXPTR padptr ;   /* current pad */
@@ -336,9 +341,7 @@ Ybuster_free() ;
 /* ***************************************************************** */
 
 /* add another cell to cell list and initialize fields */
-addCell( cellName, cellType )
-char *cellName ;
-CELLTYPE  cellType ;
+void addCell( char * cellName, CELLTYPE cellType )
 {
 INT i ;
 INT *data ;
@@ -475,7 +478,7 @@ portFlagS = FALSE ;
 /* ***************************************************************** */
 
 /* perform cleanup operations on a cell */
-endCell()
+void endCell()
 {
 ERRORABORT() ;
 
@@ -534,10 +537,8 @@ BOOL direction ;
 
 /* ***************************************************************** */
 
-fixCell( fixedType, xloc, lorR, yloc, borT, xloc2, lorR2, yloc2, borT2 )
-INT fixedType ;  /* valid types - neighborhood. point, group */
-INT xloc, yloc, xloc2, yloc2 ;
-char *lorR, *borT, *lorR2, *borT2 ;
+void fixCell( INT fixedType, INT xloc, char *lorR, INT yloc, char *borT, INT xloc2, char *lorR2, INT yloc2, char *borT2 )
+//INT fixedType ;  /* valid types - neighborhood. point, group */
 {
 
 INT leftOrRight, bottomOrTop ;
@@ -612,8 +613,7 @@ if( fixedType != POINTFLAG ){
 
 } /* end fixCell */
 
-processCorners( numcorners )
-INT numcorners ;
+void processCorners( INT numcorners )
 {
 char *buster_msg ;           /* message string to used by buster */
 INT xx1, yy1, xx2, yy2 ;     /* temp points */
@@ -790,8 +790,7 @@ ptrS->orig_aspect = ptrS->aspect =
 } /* end processCorners */
 /* ***************************************************************** */
 
-addCorner( xpos, ypos )
-INT xpos, ypos ;
+void addCorner( INT xpos, INT ypos )
 {
 if( ++cornerCountS >= tileptAllocS ){
     tileptAllocS = cornerCountS + 1 ;
@@ -819,8 +818,7 @@ maxyS = MAX( maxyS, ypos ) ;
 } /* end addCorner */
 /* ***************************************************************** */
 
-initializeCorner( cell )
-INT cell ;
+void initializeCorner( INT cell )
 {
 ptrS = cellarrayG[cell] ;
 curCellTypeS = ptrS->celltype ;
@@ -828,8 +826,7 @@ cornerCountS = 0 ;
 } /* end initializeCorner */
 /* ***************************************************************** */
 
-addClass( class )
-INT class ;
+void addClass( INT class )
 {
 ERRORABORT() ;
 
@@ -842,7 +839,7 @@ if( ptrS->class >= 0 ){
 /* ***************************************************************** */
 
 /* first in the list is the initial orientation */
-initOrient( orient )
+void initOrient( orient )
 INT orient ;
 {
 ERRORABORT() ;
@@ -853,8 +850,7 @@ addOrient( orient ) ;
 /* ***************************************************************** */
 
 /* addOrient sets orientation valid for this cell */
-addOrient( orient )
-INT orient ;
+void addOrient( INT orient )
 {
 ERRORABORT() ;
 
@@ -866,17 +862,16 @@ ptrS->orientList[HOWMANYORIENT]++ ;
 /* if this routine is called it means we are reading the input of
    a previous TimberWolf run.  
 */
-set_cur_orient( orient )
-INT orient ;
+int set_cur_orient( INT orient )
 {
-ERRORABORT() ;
+ERRORABORTINT() ;
 
 ptrS->orient = orient ;
 } /* end set_cur_orient */
 /* ***************************************************************** */
 
 /* load aspect ratios */
-addAspectBounds( lowerBound, upperBound )
+void addAspectBounds( lowerBound, upperBound )
 DOUBLE lowerBound, upperBound ;
 {
 ERRORABORT() ;
@@ -986,7 +981,7 @@ char *pinName, *signal ;
 } /* add pin and net */
 /* ***************************************************************** */
 
-addPin( pinName, signal, layer, pinType )
+void addPin( pinName, signal, layer, pinType )
 char *pinName ;
 char *signal ;
 INT layer ;
@@ -1050,7 +1045,7 @@ INT pinType ;
 	spinptrS->hierarchy = NONE ;
 	spinptrS->parent = NULL ;
 	/* build the restrict field and initialize HOWMANY [0] to 0 */
-	spinptrS->restrict = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
+	spinptrS->restrict1 = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
 	spinptrS->permute = FALSE ;
 	spinptrS->fixed = FALSE ;
 	spinptrS->ordered = FALSE ;
@@ -1084,7 +1079,7 @@ INT pinType ;
 } /* end addPin */
 /* ***************************************************************** */
 
-set_pin_pos( xpos, ypos )
+void set_pin_pos( xpos, ypos )
 INT xpos, ypos ;
 {
     INT side ;
@@ -1122,7 +1117,7 @@ INT xpos, ypos ;
 } /* end set_pin_pos */
 /* ***************************************************************** */
 
-static check_pos( pinname, xpos, ypos )
+static void check_pos( pinname, xpos, ypos )
 char *pinname ;
 INT xpos, ypos ;
 {
@@ -1135,7 +1130,7 @@ INT xpos, ypos ;
 } /* end check_pos */
 
 /* add an equivalent pin-updates the pin position to effective position */
-addEquivPin( pinName, layer, xpos, ypos, pinType )
+void addEquivPin( pinName, layer, xpos, ypos, pinType )
 char *pinName ;
 INT layer ; 
 INT xpos, ypos ;
@@ -1208,22 +1203,22 @@ INT pinType ;
     eqptr->layer = layer ;
     if( pinType == ADDEQUIVTYPE ){
 	/* build the restrict field and initialize HOWMANY [0] to 0 */
-	eqptr->restrict = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
+	eqptr->restrict1 = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
     } else {
-	eqptr->restrict = NULL ;
+	eqptr->restrict1 = NULL ;
     }
 
 } /* end addEquivPin */
 /* ***************************************************************** */
 
-set_restrict_type( object )
+void set_restrict_type( object )
 INT object ;
 {
     cur_restrict_objS = object ;
 }
 /* ***************************************************************** */
 
-addSideRestriction( side )
+void addSideRestriction( side )
 INT side ;
 {
 INT howmany ;
@@ -1245,25 +1240,25 @@ if( side < 0 || side > cornerCountS ) {
 switch( cur_restrict_objS ){ 
     case PINGROUPTYPE:
 	spin = pingroupS->softinfo ;
-	howmany = ++(spin->restrict[HOWMANY]) ;
-	spin->restrict = (INT *) Ysafe_realloc( spin->restrict,
+	howmany = ++(spin->restrict1[HOWMANY]) ;
+	spin->restrict1 = (INT *) Ysafe_realloc( spin->restrict1,
 	    (howmany+1)*sizeof(INT) ) ;
-	spin->restrict[howmany] = side ;
+	spin->restrict1[howmany] = side ;
 	break ;
     case SOFTPINTYPE:
     case SOFTEQUIVTYPE:
 	spin = pinS->softinfo ;
-	howmany = ++(spin->restrict[HOWMANY]) ;
-	spin->restrict = (INT *) Ysafe_realloc( spin->restrict,
+	howmany = ++(spin->restrict1[HOWMANY]) ;
+	spin->restrict1 = (INT *) Ysafe_realloc( spin->restrict1,
 	    (howmany+1)*sizeof(INT) ) ;
-	spin->restrict[howmany] = side ;
+	spin->restrict1[howmany] = side ;
 	break ;
     case ADDEQUIVTYPE:
 	eqptr = softpinS->eqptr ;
-	howmany = ++(eqptr->restrict[HOWMANY]) ;
-	eqptr->restrict = (INT *) Ysafe_realloc( eqptr->restrict,
+	howmany = ++(eqptr->restrict1[HOWMANY]) ;
+	eqptr->restrict1 = (INT *) Ysafe_realloc( eqptr->restrict1,
 	    (howmany+1)*sizeof(INT) ) ;
-	eqptr->restrict[howmany] = side ;
+	eqptr->restrict1[howmany] = side ;
 	break ;
 } /* end switch on current object */
 
@@ -1271,7 +1266,7 @@ switch( cur_restrict_objS ){
 /* ***************************************************************** */
 
 
-add_pinspace( lower, upper )
+void add_pinspace( lower, upper )
 DOUBLE lower ;
 DOUBLE upper ;
 {
@@ -1319,7 +1314,7 @@ DOUBLE upper ;
 } /* end add_pinspace */
 /* ***************************************************************** */
 
-add_soft_array()
+void add_soft_array()
 {
     INT i ;
     PINBOXPTR *sarray ; 
@@ -1338,7 +1333,7 @@ add_soft_array()
 }
 /* end add_soft_array */
 
-start_pin_group( pingroup, permute )
+void start_pin_group( pingroup, permute )
 char *pingroup ;
 BOOL permute ;
 {
@@ -1409,14 +1404,14 @@ spin->hierarchy = ROOT ;
 spin->lowerbound = 0.0 ;
 spin->upperbound = 1.0 ;
 spin->children = (PINBOXPTR *) Ysafe_malloc( sizeof(PINBOXPTR) ) ;
-spin->restrict = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
+spin->restrict1 = (INT *) Ysafe_calloc( 1, sizeof(INT) ) ;
 spin->parent = NULL ;
 
 } /* end start_pin_group */
 /* ***************************************************************** */
 
 /* add this pad to the current pad group */
-add2pingroup( pinName, ordered ) 
+void add2pingroup( pinName, ordered ) 
 char *pinName ;
 BOOL ordered ;  /* ordered flag is true if padgroup is fixed */
 {
@@ -1510,7 +1505,7 @@ return ;
 } /* end add2pingroup */
 /* ***************************************************************** */
 
-addSideSpace( lower, upper )
+void addSideSpace( lower, upper )
 DOUBLE lower ;
 DOUBLE upper ;
 {
@@ -1540,7 +1535,7 @@ DOUBLE upper ;
 } /* end addSideSpace */
 /* ***************************************************************** */
 
-addPadSide( side  )
+void addPadSide( side  )
 char *side ;
 {
 
@@ -1578,7 +1573,7 @@ char *side ;
 /* ***************************************************************** */
 
 /* set whether a pad group can be permuted */
-setPermutation( permuteFlag ) 
+void setPermutation( int permuteFlag ) 
 {
 ERRORABORT() ;
 pptrS->permute = permuteFlag ;
@@ -1586,7 +1581,7 @@ pptrS->permute = permuteFlag ;
 /* ***************************************************************** */
 
 /* add this pad to the current pad group */
-add2padgroup( padName, ordered ) 
+void add2padgroup( padName, ordered ) 
 char *padName ;
 BOOL ordered ;  /* ordered flag is true if pad is ordered in padgroup */
 {
@@ -1656,7 +1651,7 @@ return ;
 
 } /* end add2PadGroup */
 /* ***************************************************************** */
-add_cell_to_group( cellName ) 
+void add_cell_to_group( cellName ) 
 char *cellName ;
 {
 GLISTPTR tempCell ;
@@ -1698,7 +1693,7 @@ cptr->class = unique_classG ;
 } /* end add_cell_to_group */
 
 /* add a cell to the instance array of the defining cell */
-add_instance( instName )
+void add_instance( instName )
 char *instName ;
 {
     if( cellinstanceS++ == 0 ){
@@ -1765,7 +1760,7 @@ INT get_tile_count()
     return( tileptAllocS / 2 ) ;
 } /* end get_tile_count() */
 
-add_analog( numcorners )
+void add_analog( numcorners )
 INT numcorners ;
 {
     ERRORABORT() ;
@@ -1786,8 +1781,8 @@ INT numcorners ;
 	analogS->num_corners = numcorners ;
 	cornerCountS = 0 ;
     } else {
-	analogS->x_contour = NIL(INT) ;
-	analogS->y_contour = NIL(INT) ;
+	analogS->x_contour = NIL(INT *) ;
+	analogS->y_contour = NIL(INT *) ;
 	analogS->num_corners = 0 ;
     }
     analogS->current = INIT_CURRENT ;
@@ -1796,7 +1791,7 @@ INT numcorners ;
 
 } /* end add_analog */
 
-add_pin_contour( x, y )
+void add_pin_contour( x, y )
 INT x, y ;
 {
     if( cornerCountS >= analogS->num_corners ){
@@ -1812,7 +1807,7 @@ INT x, y ;
 } /* end start_pin_contour */
 
 
-add_current( current )
+void add_current( current )
 FLOAT current ;
 {
     if(!(analogS)){
@@ -1821,7 +1816,7 @@ FLOAT current ;
     analogS->current = current ;
 } /* end add_current */
 
-add_power( power )
+void add_power( power )
 FLOAT power ;
 {
     if(!(analogS)){
@@ -1830,7 +1825,7 @@ FLOAT power ;
     analogS->power = power ;
 } /* end add_power */
 
-no_layer_change()
+void no_layer_change()
 {
     if(!(analogS)){
 	add_analog( 0 ) ;
@@ -1838,7 +1833,7 @@ no_layer_change()
     analogS->no_layer_change = TRUE ;
 } /* end no_cross_under */
 
-process_pin()
+void process_pin()
 {
     INT i ;                      /* point counter */
     INT side ;                   /* current side for pin */
