@@ -74,9 +74,6 @@ REVISIONS:  Mar  8, 1988 - added lambda and init_acc ;
 	    Fri Oct 18 00:15:59 EDT 1991 - now scale block when calling
 		TimberWolf recursively.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) readpar.c version 3.20 11/23/91" ;
-#endif
 
 #include <string.h>
 #include <custom.h>
@@ -84,6 +81,7 @@ static char SccsId[] = "@(#) readpar.c version 3.20 11/23/91" ;
 #include <yalecad/file.h>
 #include <yalecad/string.h>
 #include <yalecad/yreadpar.h>
+#include "readpar.h"
 
 #define DEFAULTLAMBDA 0.1
 #define INIT_ACCEPTANCE 0.99999
@@ -102,14 +100,14 @@ static INT gridYS = INT_MIN ;
 
 
 
-static init_read_par();
-static readparam();
-static process_readpar();
-static err_msg();
+static void init_read_par();
+static void readparam();
+static void process_readpar();
+static void err_msg();
 
 
 
-readpar()
+void readpar()
 {
     init_read_par() ;
     readparam( TWMC ) ;
@@ -117,7 +115,7 @@ readpar()
     process_readpar() ;
 }
 
-static init_read_par()
+static void init_read_par()
 {
     /* set the default values */
     offsetG     = 0  ;
@@ -163,7 +161,7 @@ static init_read_par()
 
 
 
-static readparam( parfile )
+static void readparam( parfile )
 INT parfile ;
 {
 
@@ -483,7 +481,7 @@ INT parfile ;
     }
 } /* end readpar */
 
-static process_readpar()
+static void process_readpar()
 {
     char *layer ;             /* name of layer */
     INT i ;                   /* counter */
@@ -675,7 +673,7 @@ static process_readpar()
     return ;
 } /* end process_readpar */
 
-static err_msg( keyword ) 
+static void err_msg( keyword ) 
 char *keyword ;
 {
     OUT2("The value for %s was", keyword );
