@@ -56,11 +56,6 @@ DATE:	    Mar 27, 1989
 REVISIONS:  Sat Dec 15 22:08:21 EST 1990 - modified pinloc values
 		so that it will always be positive.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) cglbroute.c (Yale) version 4.5 12/15/90" ;
-#endif
-#endif
 
 #include "standard.h"
 #include "main.h"
@@ -83,7 +78,7 @@ static INT LswitchsegS , svalueS , evalueS ;
 static INT *crowdmaxS , glb_crowdmaxS , *node_rightS ;
 static DOUBLE  ctrackContS , factor_hereS , factor_oneS , factor_twoS ;
 
-cglb_initial()
+void cglb_initial()
 {
 
 INT i , j , net , x , tilted_seg ;
@@ -147,7 +142,7 @@ fprintf(fpoG," the number of tilted segment = %d\n", tilted_seg ) ;
 }
 
 
-proj_tree_to_grid( )
+void proj_tree_to_grid( )
 {
 
 SEGBOXPTR segptr ;
@@ -294,7 +289,7 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
 }
 
 
-set_cbucket( )
+void set_cbucket( )
 {
 
 HCAPPTR hcaptr , headptr ;
@@ -366,7 +361,7 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
 }
 
 
-cglbroute()
+void cglbroute()
 {
 
 SEGBOXPTR segptr ;
@@ -694,7 +689,7 @@ while( ++trys < maxtrys ) {
 }
 
 
-free_cglb_initial()
+void free_cglb_initial()
 {
 INT i , j , last_j , row ;
 
@@ -718,7 +713,7 @@ Ysafe_free( swLsegptrS ) ;
 }
 
 
-reinitial_Hdensity()
+void reinitial_Hdensity()
 {
 
 INT i , j ;
@@ -731,7 +726,7 @@ for( i = 1 ; i <= numRowsG ; i++ ) {
 }
 
 
-update_switchvalue()
+void update_switchvalue()
 {
 
 INT net , x , tilted_seg ;
@@ -792,7 +787,7 @@ fprintf(fpoG," the number of switchable L segment = %d\n", LswitchsegS );
 }
 
 
-rebuild_cbucket()
+void rebuild_cbucket()
 {
 INT row , j , last_j ;
 HCAPPTR hcaptr , headptr ;
@@ -843,7 +838,7 @@ for( row = 1 ; row <= numRowsG ; row++ ) {
 
 
 #ifdef DEBUG
-check_cbucket()
+void check_cbucket()
 {
 INT row, j ;
 HCAPPTR dptr , denptr ;
