@@ -61,11 +61,6 @@ DATE:	    Mar 27, 1989
 REVISIONS:  Aug 27, 1990 - modified shift so it only shifts if not
 		enough room for pads.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) coarseglb.c (Yale) version 4.10 12/9/91" ;
-#endif
-#endif
 
 #include "standard.h"
 #include "groute.h"
@@ -78,6 +73,19 @@ static char SccsId[] = "@(#) coarseglb.c (Yale) version 4.10 12/9/91" ;
 /* static definitions */
 static INT *accumulate_feedS , *feed_diffS , *diff_in_rowfeedS ;
 static INT *feed_shortS , half_hzsepS , right_Pads_left_edgeS ;
+INT set_node(INT x );
+
+/* local functions */
+static int space_for_feed(void);
+void set_up_grid( );
+void initialize_feed_need();
+void feed_config( );
+void compute_feed_diff( INT iteration );
+void update_feed_config( INT iteration );
+INT no_of_feedthru_cells();
+void addin_feedcell();
+void final_feed_config();
+void free_cglb_data();
 
 /* global definitions */
 INT longest_row_lengthG ;
@@ -89,13 +97,13 @@ extern INT actual_feed_thru_cells_addedG ;
 extern BOOL no_feed_at_endG ;
 extern BOOL ignore_feedsG ;
 
-coarseglb() 
+void coarseglb() 
 {
 
 INT shift ;
 INT iteration = 0 ;
 
-assign_row_to_pin() ;
+void assign_row_to_pin() ;
 if( case_unequiv_pinG ) {
     unequiv_pin_pre_processing() ;
 }
@@ -154,7 +162,7 @@ free_cglb_data( ) ;
 }
 
 
-assign_row_to_pin()
+void assign_row_to_pin()
 {
 
 CBOXPTR cellptr ;
@@ -172,7 +180,7 @@ for( i = 1 ; i <= numcellsG ; i++ ) {
 
 
     
-set_up_grid( )
+void set_up_grid( )
 {
 
 INT i , j , x , row_rite ;
@@ -278,7 +286,7 @@ for( cell = numcellsG + 1 ; cell <= lastpadG ; cell++ ) {
 }
 }
 
-initialize_feed_need()
+void initialize_feed_need()
 {
 
 INT i , row ;
@@ -296,7 +304,7 @@ feed_config() ;
 }
 
 
-feed_config( )
+void feed_config( )
 {
 
 INT row , cell , cxcenter , k ;
@@ -324,8 +332,7 @@ for( cell = 1 ; cell <= numcellsG ; cell++ ) {
 }
 
 
-set_node( x )
-INT x ;
+INT set_node(INT x )
 {
 
 DOUBLE h ;
@@ -341,8 +348,7 @@ if( h < 1 ) {
 }
 
 
-compute_feed_diff( iteration )
-INT iteration ;
+void compute_feed_diff( INT iteration )
 {
 
 INT i , j , k , range , left_node , rite_node ;
@@ -404,7 +410,7 @@ for( i = 1 ; i <= numRowsG ; i++ ) {
 }
 
 
-space_for_feed( )
+static int space_for_feed(void)
 {
 
 PINBOXPTR pinptr ;
@@ -526,8 +532,7 @@ return( shiftFlag ) ;
 }
 
 
-update_feed_config( iteration )
-INT iteration ;
+void update_feed_config( INT iteration )
 {
 
 INT cell , padside , shift ;
@@ -655,7 +660,7 @@ if( rowsG == 0 && blk_most_riteG >= right_Pads_left_edgeS ) {
 }
 
 
-no_of_feedthru_cells()
+INT no_of_feedthru_cells()
 {
 
 INT i , row , n , difference , lastcell_rite , total_feedthrus ;
@@ -697,7 +702,7 @@ return( total_feedthrus ) ;
 }
 
 
-addin_feedcell()
+void addin_feedcell()
 {
 
 INT row , i , k , r , last , feednum , row_left ;
@@ -822,7 +827,7 @@ TWCLOSE(fp) ;
 }
 
 
-final_feed_config( )
+void final_feed_config( )
 {
 
 IPBOXPTR imptr ;
@@ -881,7 +886,7 @@ printf("\n  longest Row is:%d   Its length is:%d\n",
 }
 
 
-free_cglb_data()
+void free_cglb_data()
 {
 
 INT i , net ;
