@@ -1,6 +1,7 @@
 /*
  *   Copyright (C) 1989-1991 Yale University
  *   Copyright (C) 2013 Tim Edwards <tim@opencircuitdesign.com>
+ *   Copyright (C) 2015 Staf Verhaegen <staf@stafverhaegen.be>
  *
  *   This work is distributed in the hope that it will be useful; you can
  *   redistribute it and/or modify it under the terms of the
@@ -48,11 +49,6 @@ REVISIONS:  Fri Jan 25 18:29:22 PST 1991 - fixed problem with
 	    Tue Mar 19 16:27:35 CST 1991 - fixed calculation
 		problem with rowSep.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) configure.c (Yale) version 4.12 3/19/91" ;
-#endif
-#endif
 
 #define CONFIG_VARS
 
@@ -87,8 +83,10 @@ static INT widthS ;
 static INT mttshiftS ;
 static INT mbbshiftS ;
 
+void random_placement();
 
-configure() 
+
+void configure() 
 {
 
 INT block ;
@@ -952,7 +950,7 @@ return ;
 
 
 
-random_placement()
+void random_placement()
 {
 
 INT cell , row , borient ,  blk , widthS ;
@@ -1044,6 +1042,8 @@ for( cell = 1 ; cell <= numcellsG - extra_cellsG ; cell++ ) {
     }
     filledTo[block] += widthS ;
 }
+Ysafe_free( filledTo );
+Ysafe_free( endRow );
 /* now finish by placing the pads */
 placepads() ;
 return ;
