@@ -1,6 +1,7 @@
 /*
  *   Copyright (C) 1989-1992 Yale University
  *   Copyright (C) 2015 Tim Edwards <tim@opencircuitdesign.com>
+ *   Copyright (C) 2015 Staf Verhaegen <staf@stafverhaegen.be>
  *
  *   This work is distributed in the hope that it will be useful; you can
  *   redistribute it and/or modify it under the terms of the
@@ -80,11 +81,6 @@ REVISIONS:  Sat Dec 15 22:08:21 EST 1990 - modified pinloc values
 	    Tue May 12 22:23:31 EDT 1992 - fixed problem with orientation
 		movement and added placement_improve switch.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) globe.c (Yale) version 4.24 5/12/92" ;
-#endif
-#endif
 
 #define GLOBE_VARS
 
@@ -101,6 +97,8 @@ static char SccsId[] = "@(#) globe.c (Yale) version 4.24 5/12/92" ;
 #define CARL_NEW
 #define PICK_INT(l,u) (((l)<(u)) ? ((RAND % ((u)-(l)+1))+(l)) : (l))
 
+INT cell_rotate(INT row , INT index );
+
 /* global variables */
 BOOL connectFlagG ;
 
@@ -110,6 +108,18 @@ extern BOOL placement_improveG ;
 
 static LONG swap_cost( P1(BOOL perim_flag ) ) ;
 
+void free_static_in_globe();
+void preFeedAssgn();
+void FeedAssgn(INT row );
+void row_seg_intersect(PINBOXPTR ptr1 , PINBOXPTR ptr2 , SEGBOXPTR segptr );
+void copy_workerS_field(FEED_SEG_PTR aptr, FEED_SEG_PTR bptr );
+void assgn_impin(IPBOXPTR imptr , FEED_SEG_PTR fsptr , int row );
+void relax_padPins_pinloc();
+void relax_unequiv_pinloc();
+void elim_unused_feedsSC();
+void rebuild_nextpin();
+void rebuild_cell_paths();
+
 /* static variables */
 static INT *wk_headS , max_feed_in_a_rowS ;
 static INT *L_jogS ;
@@ -118,7 +128,7 @@ static INT wkS ;
 static LONG global_wire_lengthS ;
 static INT swap_limitS ;
 
-globe() 
+int globe() 
 {
 
 INT row , net , cost , last_cost , swaps , found , total_final_cost ;
@@ -127,6 +137,7 @@ INT last_global_wire , total_reduction , index , i , j , k , check ;
 INT iterations, initial_time, last_index ;
 LONG initial_wire ;
 PINBOXPTR netptr , cnetptr ;
+int ok = 1;
 
 implicit_pins_usedG = 0 ;
 decide_boundary() ;
@@ -151,7 +162,8 @@ elim_unused_feedsSC() ;
 
 /* if( rigidly_fixed_cellsG ) { */
 if( refine_fixed_placement() == 0 ) {
-    return(0);
+    ok = 0;
+    goto out;
 }
 /* } */
 
@@ -295,14 +307,21 @@ if( case_unequiv_pinG ) {
     }
 }
 
+out:
 free_chan_seg() ;
 free_z_memory() ;
 
-return(1) ;
+return(ok) ;
 }
 
 
-preFeedAssgn()
+void globe_free_up()
+{
+    netgraph_free_up();
+}
+
+
+void preFeedAssgn()
 {
 
 SEGBOXPTR segptr , nextptr ;
@@ -336,7 +355,7 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
 }
 
 
-free_static_in_globe()
+void free_static_in_globe()
 {
 
 INT i ;
@@ -352,8 +371,7 @@ Ysafe_free( total_feed_in_the_rowG ) ;
 
 
 #ifdef CARL_NEW
-FeedAssgn( row )
-INT row ;
+void FeedAssgn(INT row )
 {
 
 PINBOXPTR netptr , ptr1 , ptr2 ;
@@ -653,6 +671,8 @@ for( assign_iter = 1 ; assign_iter <= num_parts ; assign_iter++ ) {
     /* end of this fly-by-night attempt	*/
 }
 
+Ysafe_free( assigned_to_track ) ;
+
 
 
 #else
@@ -701,8 +721,7 @@ return ;
 }
 #else
 
-FeedAssgn( row )
-INT row ;
+void FeedAssgn(INT row )
 {
 
 PINBOXPTR netptr , ptr1 , ptr2 ;
@@ -878,9 +897,7 @@ for( k = 1 ; k <= chan_node_no ; k++ ) {
 #endif
 
 
-row_seg_intersect( ptr1 , ptr2 , segptr )
-PINBOXPTR ptr1 , ptr2 ;
-SEGBOXPTR segptr ;
+void row_seg_intersect(PINBOXPTR ptr1 , PINBOXPTR ptr2 , SEGBOXPTR segptr )
 {
 
 INT i ;
@@ -905,8 +922,7 @@ workerS[ wkS ]->segptr = segptr ;
 }
 
 
-copy_workerS_field( aptr, bptr )
-FEED_SEG_PTR aptr, bptr ;
+void copy_workerS_field(FEED_SEG_PTR aptr, FEED_SEG_PTR bptr )
 {
 aptr->netptr = bptr->netptr ;
 aptr->refer  = bptr->refer ;
@@ -915,9 +931,7 @@ aptr->segptr = bptr->segptr ;
 
 
 #ifdef CARL_NEW
-assgn_impin( imptr , fsptr , row )
-IPBOXPTR imptr ;
-FEED_SEG_PTR fsptr ;
+void assgn_impin(IPBOXPTR imptr , FEED_SEG_PTR fsptr , int row )
 {
 
 INT net ;
@@ -937,6 +951,7 @@ if( fsptr->segptr ) {
 
     segptr = fsptr->segptr ;
     netptr->xpos = imptr->xpos ;
+    /* FIXME: the following line leaks memory but just freeing it gives freed memory access */
     segptr->pin1ptr = netptr ;
     ptr1 = segptr->pin1ptr ;
     ptr2 = segptr->pin2ptr ;
@@ -984,9 +999,7 @@ if( strncmp( carrayG[netptr->cell]->cname, "twfeed", 6 ) == STRINGEQ ){
 }
 }
 #else
-assgn_impin( imptr , fsptr , row )
-IPBOXPTR imptr ;
-FEED_SEG_PTR fsptr ;
+void assgn_impin(IPBOXPTR imptr , FEED_SEG_PTR fsptr , int row )
 {
 
 INT net ;
@@ -1032,7 +1045,7 @@ netptr->eqptr->pinname = imptr->eqpinname ;
 }
 
 
-local_Assgn( row , node )
+void local_Assgn( row , node )
 INT row , node ;
 {
 
@@ -1147,7 +1160,7 @@ feedptr[node]->needed = 0 ;
 
 
 
-unequiv_pin_pre_processing()
+void unequiv_pin_pre_processing()
 {
 DBOXPTR dimptr ;
 PINBOXPTR ptr ;
@@ -1204,7 +1217,7 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
 }
 
 
-relax_padPins_pinloc()
+void relax_padPins_pinloc()
 {
 INT i ;
 PINBOXPTR pinptr ;
@@ -1221,7 +1234,7 @@ for( i = lastpadG ; i > numcellsG ; i-- ) {
 }
 
 
-relax_unequiv_pinloc()
+void relax_unequiv_pinloc()
 {
 DBOXPTR dimptr ;
 PINBOXPTR ptr ;
@@ -1243,7 +1256,7 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
 }
 
 
-check_unequiv_connectivity()
+int check_unequiv_connectivity()
 {
 INT net, channel, correctness ;
 ADJASEG *adj ;
@@ -1393,7 +1406,7 @@ BOOL perim_flag ;
 
 
 
-improve_place_sequential( row , index )
+int improve_place_sequential( row , index )
 INT row , index ;
 {
 
@@ -1607,8 +1620,7 @@ if( accept_greedy( (INT)(global_wire-new_global_wire), timingcostG-newtimepenal,
 }
 
 
-cell_rotate( row , index )
-INT row , index ;
+INT cell_rotate(INT row , INT index )
 {
 
 INT cell, swap ;
@@ -1763,7 +1775,7 @@ if( accept_greedy( (INT)(global_wire-new_global_wire), timingcostG-newtimepenal,
 }
 } /* end cell_rotate() */
 
-elim_unused_feedsSC()
+void elim_unused_feedsSC()
 {
 
 CBOXPTR ptr , cellptr , first_cptr , last_cptr ;
@@ -1855,10 +1867,11 @@ fprintf( fpoG, "\nLONGEST Row is:%d   Its length is:%d\n",
 			    longest_row , max_length ) ;
 
 
+Ysafe_free( row_len );
 return ;
 }
  
-rebuild_nextpin()
+void rebuild_nextpin()
 {
     INT net, cell ;
     PINBOXPTR netptr , cnetptr ;
@@ -1891,7 +1904,7 @@ rebuild_nextpin()
     }
 } /* end rebuild_nextpin */
 
-rebuild_cell_paths()
+void rebuild_cell_paths()
 {
     INT i ;
     CBOXPTR ptr ;
