@@ -54,9 +54,6 @@ REVISIONS:  Jun 21, 1990 - added graphics abort macro.
 	    Tue May  7 00:09:43 EDT 1991 - added TWsetFrame 
 		initialization and draw orientation markers.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) graphics.c version 4.21 5/15/92" ;
-#endif
 
 #include "standard.h"
 #include "main.h"
@@ -115,11 +112,16 @@ static INT  drawNetS = 0 ; /* draw nets 0:none 1...n:net >numnets:all */
 static INT  pinsizeS ;     /* size of the pin */
 
 
-static draw_fs();
+static void draw_fs();
 extern VOID draw_a_cell( INT );
-extern INT draw_the_data() ;
+extern void draw_the_data() ;
+void graphics_dump();
+void reset_heat_index();
+void closegraphics();
 
-initGraphics( argc, argv, windowId )
+void setGraphicWindow();
+
+void initGraphics( argc, argv, windowId )
 INT argc ;
 char *argv[] ;
 INT windowId ;
@@ -149,7 +151,7 @@ INT windowId ;
     if( windowId ){
 	/* init windows as a parasite */
 	if(!(TWinitParasite(argc,argv,TWnumcolors(),TWstdcolors(),
-	    FALSE,menuS, draw_the_data, windowId ))){
+	    FALSE,menuS, (INT (*)()) draw_the_data, windowId ))){
 	    M(ERRMSG,"initGraphics","Aborting graphics.");
 	    doGraphicsG = FALSE ;
 	    avoidDump = TRUE ;
@@ -158,7 +160,7 @@ INT windowId ;
     } else {
 	/* init window as a master */
 	if(!(TWinitGraphics(argc,argv,TWnumcolors(),TWstdcolors(),FALSE,
-	    menuS,draw_the_data ))){
+	    menuS, (INT (*)()) draw_the_data ))){
 	    M(ERRMSG,"initGraphics","Aborting graphics.");
 	    doGraphicsG = FALSE ;
 	    avoidDump = TRUE ;
@@ -180,7 +182,7 @@ INT windowId ;
 
 } /* end initGraphics */
 
-init_heat_index()
+void init_heat_index()
 {
     GRAPHICSABORT ;
 
@@ -191,7 +193,7 @@ init_heat_index()
     initS = TRUE ;
 } /* end init_heat_index */
 
-expand_heat_index()
+void expand_heat_index()
 {
     INT oldnum, i;
 
@@ -209,7 +211,7 @@ expand_heat_index()
     }
 } /* end expand_heat_index */
 
-setGraphicWindow() 
+void setGraphicWindow() 
 {
     INT  expand ;
     INT  minx ;
@@ -247,7 +249,7 @@ setGraphicWindow()
 } /* end setGraphicWindow */
 
 /* heart of the graphic syskem processes user input */
-process_graphics()
+void process_graphics()
 {
 
     INT x, y ;           /* coordinates from pointer */
@@ -419,7 +421,7 @@ process_graphics()
 
 /* the graphics program can draw the results at each desired */
 /* timestep. */
-INT draw_the_data()
+void draw_the_data()
 {
 
     INT  i ;
@@ -597,7 +599,7 @@ INT cell ;
 } /* end draw a cell */
 
 
-static draw_fs( cptr )
+static void draw_fs( cptr )
 CBOXPTR cptr ;
 {
     INT x[10], y[10] ;   /* only 10 points to an F */
@@ -638,7 +640,7 @@ CBOXPTR cptr ;
     TWdrawArb( 0, FCOLOR, NIL(char *) ) ;
 } /* end draw_fs */
 
-erase_a_cell( cell, x, y )
+void erase_a_cell( cell, x, y )
 INT cell ;
 INT x, y ;
 {
@@ -676,7 +678,7 @@ INT x, y ;
 
 
 /* dumps the data to a file for future study */
-graphics_dump() 
+void graphics_dump() 
 {
     /* now change mode to dump to file */
     TWsetMode(1) ;
@@ -687,7 +689,7 @@ graphics_dump()
 }
 
 /* see if uses wishes an interrupt otherwise just draw the data */
-check_graphics( drawFlag )
+void check_graphics( drawFlag )
 BOOL drawFlag ;
 {
     if( doGraphicsG ){
@@ -700,7 +702,7 @@ BOOL drawFlag ;
     }
 } /* end check_graphics */
 
-graphics_cell_update( cell )
+void graphics_cell_update( cell )
 INT cell ;
 {
     GRAPHICSABORT ;
@@ -714,7 +716,7 @@ INT cell ;
     draw_a_cell( cell ) ;
 } /* end graphics_cell_update */
 
-graphics_cell_attempt( cell )
+void graphics_cell_attempt( cell )
 INT cell ;
 {
     GRAPHICSABORT ;
@@ -723,7 +725,7 @@ INT cell ;
     heat_attemptS[cell]++ ;
 } /* end graphics_cell_attempt */
 
-reset_heat_index()
+void reset_heat_index()
 {
     INT i ; /* counter */
 
@@ -734,7 +736,7 @@ reset_heat_index()
     }
 } /* end reset_heat_index */
 
-set_update( flag )
+void set_update( flag )
 BOOL flag ;
 {
     updateS = flag ;
@@ -743,7 +745,7 @@ BOOL flag ;
 #endif /* NOGRAPHICS */
 
 /* close graphics window on fault */
-closegraphics( )
+void closegraphics( )
 {
     if( doGraphicsG ){
 	G( TWcloseGraphics() ) ;
