@@ -1,6 +1,7 @@
 /*
  *   Copyright (C) 1989-1991 Yale University
  *   Copyright (C) 2015 Tim Edwards <tim@opencircuitdesign.com>
+ *   Copyright (C) 2015 Staf Verhaegen <staf@stafverhaegen.be>
  *
  *   This work is distributed in the hope that it will be useful; you can
  *   redistribute it and/or modify it under the terms of the
@@ -67,11 +68,6 @@ REVISIONS:  Thu Feb  7 00:10:27 EST 1991 - now also support old
 	    Thu Dec  5 21:58:34 EST 1991 - fixed problem with
 		macro cell output pins.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) outpins.c (Yale) version 4.9 12/5/91" ;
-#endif
-#endif
 
 #include <string.h>
 #include "standard.h"
@@ -105,14 +101,14 @@ static BOOL old_formatS = FALSE ;
 
 char *find_layer( /* pinname, layer */ ) ;
 
-static do_outpins();
-static do_macropins();
-static do_left_vertical_channel();
-static do_right_vertical_channel();
-static do_bottom_channel();
-static do_top_channel();
+static void do_outpins();
+static void do_macropins();
+static void do_left_vertical_channel();
+static void do_right_vertical_channel();
+static void do_bottom_channel();
+static void do_top_channel();
 
-outpins()
+void outpins()
 {
 
 PINBOXPTR ptr1 , ptr2 , ptr ;
@@ -270,15 +266,10 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
     }
     /* the groupS index for vertex_G[i] = groupS[ find_groupS_name(i) ] */
 }
-Ysafe_free( count_G ) ;
-Ysafe_free( father_G ) ;
-Ysafe_free( root_G ) ;
-Ysafe_free( stack_G ) ;
-Ysafe_free( vertex_G ) ;
-Ysafe_free( groupS ) ;
-Ysafe_free( hashS ) ;
-Ysafe_free( left_edgeS ) ;
-Ysafe_free( rite_edgeS ) ;
+Ysafe_free( groupS ) ; groupS = NULL ;
+Ysafe_free( hashS ) ; hashS = NULL ;
+Ysafe_free( left_edgeS ) ; left_edgeS = NULL ;
+Ysafe_free( rite_edgeS ) ; rite_edgeS = NULL ;
 TWCLOSE( fpS ) ;
 }
 
@@ -295,7 +286,7 @@ TWCLOSE( fpS ) ;
  * 9. layer                                                          *
  *-------------------------------------------------------------------*/
 
-static do_outpins( ptr , flag )
+static void do_outpins( ptr , flag )
 PINBOXPTR ptr ;
 INT flag ;
 {
@@ -456,7 +447,7 @@ fprintf(fpS,"%s %d %s %s %d %d %d %d %d\n" ,
 return ;
 }
 
-static do_macropins( ptr )
+static void do_macropins( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -518,7 +509,7 @@ fprintf(fpS,"%s %d %s %s %d %d %d %d %d\n" ,
 return ;
 }
 
-static do_left_pseudo_pins( ptr , channel , groupS_number )
+static void do_left_pseudo_pins( ptr , channel , groupS_number )
 PINBOXPTR ptr ;
 INT channel , groupS_number ;
 {
@@ -558,7 +549,7 @@ netarrayG[ptr->net]->name , groupS_number , x , y ) ;
 }
 
 
-static do_right_pseudo_pins( ptr , channel , groupS_number )
+static void do_right_pseudo_pins( ptr , channel , groupS_number )
 PINBOXPTR ptr ;
 INT channel , groupS_number ;
 {
@@ -595,7 +586,7 @@ netarrayG[ptr->net]->name , groupS_number , x , y ) ;
 #endif
 }
 
-static do_left_vertical_channel( ptr )
+static void do_left_vertical_channel( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -677,7 +668,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_right_vertical_channel( ptr )
+static void do_right_vertical_channel( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -742,7 +733,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_bottom_channel( ptr )
+static void do_bottom_channel( ptr )
 PINBOXPTR ptr ;
 {
 INT x , y , groupS_number , layer , i ;
@@ -828,7 +819,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_top_channel( ptr )
+static void do_top_channel( ptr )
 PINBOXPTR ptr ;
 {
 INT x , y , groupS_number , layer , i ;
@@ -941,7 +932,7 @@ INT *layer ;
 } /* end find_layer */
 
 
-set_pin_format( flag )
+void set_pin_format( flag )
 BOOL flag ;
 {
     old_formatS = flag ;
