@@ -1,5 +1,6 @@
 /*
  *   Copyright (C) 1989-1991 Yale University
+ *   Copyright (C) 2015 Staf Verhaegen <staf@stafverhaegen.be>
  *
  *   This work is distributed in the hope that it will be useful; you can
  *   redistribute it and/or modify it under the terms of the
@@ -61,11 +62,6 @@ CONTENTS:   outpins()
 DATE:	    Mar 27, 1989 
 REVISIONS:  
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) outpins1.c (Yale) version 1.3 4/18/91" ;
-#endif
-#endif
 
 #include <string.h>
 #include "standard.h"
@@ -98,14 +94,14 @@ static INT *rite_edgeS ;
 static INT *left_edgeS ;
 static FILE *fpS ;
 
-static do_outpins();
-static do_vertical_channel();
-static do_left_vertical_channel();
-static do_right_vertical_channel();
-static do_bottom_channel();
-static do_top_channel();
+static void do_outpins();
+static void do_vertical_channel();
+static void do_left_vertical_channel();
+static void do_right_vertical_channel();
+static void do_bottom_channel();
+static void do_top_channel();
 
-old_outpins()
+void old_outpins()
 {
 
 PINBOXPTR ptr1 , ptr2 , ptr ;
@@ -260,15 +256,10 @@ for( net = 1 ; net <= numnetsG ; net++ ) {
     }
     /* the group index for vertex_G[i] = groupS[ find_group_name(i) ] */
 }
-Ysafe_free( count_G ) ;
-Ysafe_free( father_G ) ;
-Ysafe_free( root_G ) ;
-Ysafe_free( stack_G ) ;
-Ysafe_free( vertex_G ) ;
-Ysafe_free( groupS ) ;
-Ysafe_free( hashS ) ;
-Ysafe_free( left_edgeS ) ;
-Ysafe_free( rite_edgeS ) ;
+Ysafe_free( groupS ) ; groupS = NULL ;
+Ysafe_free( hashS ) ; hashS = NULL ;
+Ysafe_free( left_edgeS ) ; left_edgeS = NULL ;
+Ysafe_free( rite_edgeS ) ; rite_edgeS = NULL ;
 TWCLOSE( fpS ) ;
 }
 
@@ -285,7 +276,7 @@ TWCLOSE( fpS ) ;
  * 9. 0                                                              *
  *-------------------------------------------------------------------*/
 
-static do_outpins( ptr , flag )
+static void do_outpins( ptr , flag )
 PINBOXPTR ptr ;
 int flag ;
 {
@@ -439,7 +430,7 @@ return ;
 }
 
 
-static do_pseudo_pins( ptr , channel , group_number )
+static void do_pseudo_pins( ptr , channel , group_number )
 PINBOXPTR ptr ;
 int channel , group_number ;
 {
@@ -525,7 +516,7 @@ fprintf(fpS,"%s %d PSEUDO_CELL PSEUDO_PIN %d %d %d %d 0\n" ,
 
 
 
-static do_left_pseudo_pins( ptr , channel , group_number )
+static void do_left_pseudo_pins( ptr , channel , group_number )
 PINBOXPTR ptr ;
 int channel , group_number ;
 {
@@ -565,7 +556,7 @@ netarrayG[ptr->net]->name , group_number , x , y ) ;
 }
 
 
-static do_right_pseudo_pins( ptr , channel , group_number )
+static void do_right_pseudo_pins( ptr , channel , group_number )
 PINBOXPTR ptr ;
 int channel , group_number ;
 {
@@ -604,7 +595,7 @@ netarrayG[ptr->net]->name , group_number , x , y ) ;
 
 
 
-static do_vertical_channel( ptr )
+static void do_vertical_channel( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -646,7 +637,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_left_vertical_channel( ptr )
+static void do_left_vertical_channel( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -712,7 +703,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_right_vertical_channel( ptr )
+static void do_right_vertical_channel( ptr )
 PINBOXPTR ptr ;
 {
 
@@ -778,7 +769,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_bottom_channel( ptr )
+static void do_bottom_channel( ptr )
 PINBOXPTR ptr ;
 {
 int x , y , group_number , layer , i ;
@@ -860,7 +851,7 @@ for( adj = ptr->adjptr->next ; adj ; adj = adj->next ) {
 }
 
 
-static do_top_channel( ptr )
+static void do_top_channel( ptr )
 PINBOXPTR ptr ;
 {
 int x , y , group_number , layer , i ;
