@@ -85,9 +85,6 @@ REVISIONS:  Mon Nov 19 04:04:18 EST 1990 - added temperature
 	    Wed Sep 11 11:21:42 CDT 1991 - fixed for
 		new global router feed problem.
 ----------------------------------------------------------------- */
-#ifndef lint
-static char SccsId[] = "@(#) parser.c (Yale) version 4.40 5/15/92" ;
-#endif
 
 /* #define MITLL */
 
@@ -127,6 +124,13 @@ extern BOOL spacer_name_twfeedG ;
 extern BOOL rigidly_fixed_cellsG ;
 extern BOOL stand_cell_as_gate_arrayG ;
 
+void addCell( char *cellname, INT celltype );
+void add_tile(INT left, INT bottom, INT right, INT top );
+void add_padside(char * padside);
+void setPermutation( int permuteFlag );
+void add2padgroup( char *padName, BOOL ordered );
+void end_padgroup();
+
 /* below is what we expect to be a typical standard cell input */
 /* user may change parameters if they wish. Subject to change */
 #define EXPECTEDNUMCELLS  3500
@@ -144,6 +148,20 @@ extern BOOL stand_cell_as_gate_arrayG ;
     } \
 } \
 
+#define ERRORABORTINT() \
+{ \
+    if( abortS ){ \
+	return -1; /* don't do any work for errors */ \
+    } \
+} \
+
+#define ERRORABORTPOINTER() \
+{ \
+    if( abortS ){ \
+	return NULL; /* don't do any work for errors */ \
+    } \
+} \
+
 /* ##########################  STATIC definitions ########################### */
 static INT  curCellTypeS ;        /* current cell type - ie, stdcell,pad etc. */
 static INT  curNetS ;             /* current net number                       */
@@ -179,11 +197,11 @@ static INT transTableS[5][8] = {  /* translate from old pad format */
 } ;
 
 
-static layer_test();
-static check_pin();
+static void layer_test();
+static void check_pin();
 
 /* ###################### END STATIC definitions ############################ */
-static get_stat_hints()
+static void get_stat_hints()
 {
     FILE *fp ;           /* current file */
     char buffer[LRECL] ; /* temp storage */
@@ -244,12 +262,12 @@ static get_stat_hints()
 
 } /* end get_stat_hints */
 
-set_error_flag()
+void set_error_flag()
 {
     abortS = TRUE ;
 } /* set_error_flag */
 
-initialize_parser()
+void initialize_parser()
 {
     INT except ;          /* counter */
     INT width ;           /* width of exception */
@@ -309,9 +327,7 @@ initialize_parser()
 
 } /* initialize_parser */
 
-addCell( cellname, celltype )
-char *cellname ;
-INT celltype ;
+void addCell( char *cellname, INT celltype )
 {
     /* save current cell name and type for error messages */
     curCellNameS = cellname ;
@@ -409,8 +425,7 @@ INT celltype ;
 
 } /* end addCell */
 
-add_tile( left, bottom, right, top )
-INT left, bottom, right, top ;
+void add_tile(INT left, INT bottom, INT right, INT top )
 {
     INT width ;         /* width of tile */
     INT height ;        /* height of tile */
@@ -464,7 +479,7 @@ INT left, bottom, right, top ;
 
 } /* end add_tile */
 
-add_initial_orient( orient )
+void add_initial_orient( orient )
 INT orient ;
 {
 
@@ -484,7 +499,7 @@ static char *add_swap_func()
 {
     INT *data ;   /* pointer to allocated space for swap_group record */
 
-    ERRORABORT() ;
+    ERRORABORTPOINTER() ;
 
     /* how to add the data to the hash table */
     /* create space for data */
@@ -494,8 +509,7 @@ static char *add_swap_func()
     return( (char *) data ) ;
 } /* end add_swap_func */
 
-add_swap_group( swap_name )
-char *swap_name ;
+void add_swap_group(char * swap_name )
 {
     INT i ;            /* counter */
     INT *groupptr ;    /* the return group from searching in hash table */
@@ -562,7 +576,7 @@ char *swap_name ;
 
 } /* end add_swap_group */
 
-add_pingroup()
+void add_pingroup()
 {
     INT i ;    /* counter */
     INT j ;    /* counter */
@@ -590,7 +604,7 @@ add_pingroup()
 
 } /* end add_pingroup */
 
-end_pingroup()
+void end_pingroup()
 {
     pin_group_light_is_onS = 0 ;
 
@@ -600,7 +614,7 @@ end_pingroup()
     if (need_swap_groupS == TRUE) swap_groupS = 0;
 } /* end end_pingroup */
 
-static add_implicit_feed( pin_name, signal, layer, xpos, ypos )
+static void add_implicit_feed( pin_name, signal, layer, xpos, ypos )
 char *pin_name, *signal ;
 INT layer, xpos, ypos ;
 {
@@ -638,7 +652,7 @@ static char *add_net_func()
 {
     INT *data ;   /* pointer to allocated space for net record in hashtable */
 
-    ERRORABORT() ;
+    ERRORABORTPOINTER() ;
     /* how to add the data to the hash table */
     /* create space for data */
     data = (INT *) Ysafe_malloc( sizeof(INT) ) ;
@@ -649,9 +663,9 @@ static char *add_net_func()
 
 static char *add_pin_func()
 {
-    INT *data ;   /* pointer to allocated space for pin_grp_hash record */
+    PINLIST *data ;   /* pointer to allocated space for pin_grp_hash record */
 
-    ERRORABORT() ;
+    ERRORABORTPOINTER() ;
 
     /* how to add the data to the hash table */
     /* create space for data */
@@ -659,7 +673,7 @@ static char *add_pin_func()
     return( (char *) data ) ;
 } /* end add_swap_func */
 
-add_pin( pin_name, signal, layer, xpos, ypos )
+void add_pin( pin_name, signal, layer, xpos, ypos )
 char *pin_name, *signal ;
 INT layer, xpos, ypos ;
 {
@@ -796,7 +810,7 @@ INT layer, xpos, ypos ;
     if( pin_group_light_is_onS > 0 ) {
 
 	pin_ptr = (PINLISTPTR) Yhash_add( swap_group_listG[swap_groupS].pin_grp_hash,
-		ptrS->cname, add_pin_func, &newflag ) ;
+		ptrS->cname, add_pin_func, (BOOL *) &newflag ) ;
 
 	if (newflag) {
 	   /* This is the first pin group for this swap group in this cell */
@@ -861,7 +875,7 @@ INT layer, xpos, ypos ;
 
 } /* end add_pin */
 
-static check_pin( xpos, ypos, pinname )
+static void check_pin( xpos, ypos, pinname )
 INT xpos, ypos ;
 char *pinname ;
 {
@@ -888,7 +902,7 @@ char *pinname ;
     }
 } /* end check_pin */
 
-add_equiv( equiv_name, layer, eq_xpos, eq_ypos, unequiv_flag )
+void add_equiv( equiv_name, layer, eq_xpos, eq_ypos, unequiv_flag )
 char *equiv_name ;
 INT layer, eq_xpos, eq_ypos ;
 BOOL unequiv_flag ;
@@ -967,11 +981,9 @@ BOOL unequiv_flag ;
     }
 } /* end add_equiv */
 
-add_port( portname, signal, layer, xpos, ypos )
-char *portname, *signal ;
-INT xpos, ypos ;
+int add_port(char *portname, char *signal, int layer, INT xpos, INT ypos )
 {
-    ERRORABORT() ;
+    ERRORABORTINT() ;
     addCell( portname, PORTTYPE ) ;
     add_tile( 0, 0, 0, 0 ) ;
     /* now perform overrides */
@@ -987,7 +999,7 @@ INT xpos, ypos ;
 
 
 
-static layer_test( layer )
+static void layer_test( layer )
 INT layer ;
 {
     if( layer != 0 && layer != 1 && layer != 2 && layer != 3 ) {
@@ -1001,14 +1013,14 @@ INT layer ;
     }
 } /* end layer_test */
 
-init_legal_blocks( numblocks )
+void init_legal_blocks( numblocks )
 INT numblocks ;
 {
     ERRORABORT() ;
     ptrS->cclass = 0 ;
 } /* end init_legal_blocks */
 
-add_legal_blocks( block_class )
+void add_legal_blocks( block_class )
 INT block_class ;
 {
     INT  row ;            /* row counter */
@@ -1043,14 +1055,14 @@ INT block_class ;
     ptrS->cbclass[index] += bit_class ;
 } /* end add_legal_blocks */
 
-set_mirror_flag()
+void set_mirror_flag()
 {
     ERRORABORT() ;
     /* this is for the current cell */
     ptrS->orflag = 0 ;
 } /* end set_mirror_flag */
 
-add_orient( orient )
+void add_orient( orient )
 INT orient ;
 {
     ERRORABORT() ;
@@ -1058,7 +1070,7 @@ INT orient ;
     ptrS->corient = orient ;
 } /* end add_orient */
 
-fix_placement( fixed_type, from, fixed_loc, block )
+void fix_placement( fixed_type, from, fixed_loc, block )
 char *fixed_type, *fixed_loc ;
 INT from, block;
 {
@@ -1146,7 +1158,7 @@ INT from, block;
     }
 } /* end fix_placement */
 
-add_extra_cells()
+void add_extra_cells()
 {
 
     INT row ;                 /* row counter */
@@ -1257,13 +1269,13 @@ add_extra_cells()
     }	
 } /* end add_extra_cells */
 
-static INT free_swap_data( data )
+static void free_swap_data( data )
 INT *data ;
 {
     Ysafe_free( data ) ;
 } /* free_swap_data */
 
-static trans_tile( ptr, orient )
+static void trans_tile( ptr, orient )
 CBOXPTR ptr ;
 INT orient ;
 {
@@ -1286,7 +1298,7 @@ INT orient ;
     ptr->cheight = t - b ;
 } /* end trans_tile */
 
-static build_pad_group( side, sidename, padgroupname )
+static void build_pad_group( side, sidename, padgroupname )
 INT side ;
 char *sidename, *padgroupname ;
 {
@@ -1319,7 +1331,7 @@ char *sidename, *padgroupname ;
     }
 } /* end build_pad_group() */
 
-cleanup_readcells()
+void cleanup_readcells()
 {
     INT trl ;             /* total_row_length */
     INT row ;             /* row counter */
@@ -1784,14 +1796,14 @@ cleanup_readcells()
     }
 
     if( swappable_gates_existG ) {
-	Yhash_table_delete( swap_hash_tableS, free_swap_data ) ;
+	Yhash_table_delete( swap_hash_tableS, (INT  (*)()) free_swap_data ) ;
     }
 
     return ;
 } /* end cleanup_readcells */
 
 
-not_supported( object )
+void not_supported( object )
 char *object ;
 {
     sprintf( YmsgG, "%s is not supported -- sorry!\n", object ) ;
@@ -1804,7 +1816,7 @@ YHASHPTR get_net_table()
     return( net_hash_tableS ) ;
 } /* end get_net_table */
 
-add_eco()
+void add_eco()
 {
     ERRORABORT() ;
     ECOs_existG++ ;
@@ -1813,7 +1825,7 @@ add_eco()
 
 /* ***************************************************************** */
 /* added below for pad capability */
-init_corners()
+void init_corners()
 {
     minxS = INT_MAX ;
     maxxS = INT_MIN ;
@@ -1827,7 +1839,7 @@ init_corners()
     ptAllocS = 4 ;
 } /* end init_corners */
 
-add_corner( x, y )
+void add_corner( x, y )
 INT x, y ;
 {
     INT pt ;    /* point counter */
@@ -1851,7 +1863,7 @@ INT x, y ;
     pptrS->ypoints[pt] = y ;
 } /* end add_corner */
 
-process_corners()
+void process_corners()
 {
     INT xcenter ; /* center of cell */
     INT ycenter ; /* center of cell */
@@ -1892,8 +1904,7 @@ process_corners()
 } /* end process_corners */
 
 
-add_padside( padside )
-char *padside ;
+void add_padside(char * padside )
 {
     INT numsides ;         /* length of side restriction string */
     INT i ;                /* counter */
@@ -1973,7 +1984,7 @@ char *padside ;
     } 
 } /* end add_padside */
 
-add_sidespace( lower, upper )
+void add_sidespace( lower, upper )
 DOUBLE lower, upper ;
 {
     ERRORABORT() ;
@@ -2014,14 +2025,14 @@ DOUBLE lower, upper ;
 /* ***************************************************************** */
 
 /* set whether a pad group can be permuted */
-setPermutation( permuteFlag ) 
+void setPermutation( int permuteFlag ) 
 {
     ERRORABORT() ;
     pptrS->permute = permuteFlag ;
 } /* end setPermutation */
 /* ***************************************************************** */
 
-set_old_format( padside )
+void set_old_format( padside )
 char *padside ;
 {
     ERRORABORT() ;
@@ -2044,9 +2055,8 @@ char *padside ;
 } /* set_old_format */
 
 /* add this pad to the current pad group */
-add2padgroup( padName, ordered ) 
-char *padName ;
-BOOL ordered ;  /* ordered flag is true if pad is fixed in padgroup */
+void add2padgroup( char *padName, BOOL ordered ) 
+//BOOL ordered ;  /* ordered flag is true if pad is fixed in padgroup */
 {
     INT i, endofpads, endofgroups ;
 
@@ -2113,7 +2123,7 @@ BOOL ordered ;  /* ordered flag is true if pad is fixed in padgroup */
 
 } /* end add2PadGroup */
 
-end_padgroup()
+void end_padgroup()
 {
     ERRORABORT() ;
 
