@@ -65,11 +65,6 @@ REVISIONS:  Nov 23, 1990 - now use new readpar library function.
 	    Fri Nov  8 01:13:18 EST 1991 - added even the rows
 		maximally.
 ----------------------------------------------------------------- */
-#ifndef VMS
-#ifndef lint
-static char SccsId[] = "@(#) readpar.c (Yale) version 4.26 5/12/92" ;
-#endif
-#endif
 
 #define READPAR_VARS
 #define NOTSPECIFIED -1
@@ -139,12 +134,12 @@ extern BOOL doubleback_rows_start_at_oneG ;
 static BOOL abortS = FALSE ;
 static BOOL readparamS = FALSE ;
 
-static init_read_par();
-static readparam();
-static process_readpar();
-static err_msg();
+static void init_read_par();
+static void readparam();
+static void process_readpar();
+static void err_msg();
 
-readParFile()
+void readParFile()
 {
     init_read_par() ;
     readparam( TWSC ) ;
@@ -152,7 +147,7 @@ readParFile()
     process_readpar() ;
 }
 
-static init_read_par()
+static void init_read_par()
 {
     /* initialization of variables */
     SGGRG = FALSE ;
@@ -178,7 +173,7 @@ static init_read_par()
     file_conversionG = FALSE ;
 } /* end init_read_par */
 
-static readparam( parfile )
+static void readparam( parfile )
 INT parfile ;
 {
 
@@ -686,7 +681,7 @@ INT parfile ;
 } /* end  readparam */
 
 
-static process_readpar()
+static void process_readpar()
 {
 
 char *layer ;             /* name of layer */
@@ -819,7 +814,7 @@ if( track_pitchG != NOTSPECIFIED ) {
 return ;
 } /* end process_readpar */
 
-yaleIntro() 
+void yaleIntro() 
 {
     INT i ;
 
@@ -867,7 +862,7 @@ yaleIntro()
 
 } /* end yaleIntro */
 
-static err_msg( keyword ) 
+static void err_msg( keyword ) 
 char *keyword ;
 {
     OUT2("The value for %s was", keyword );
